--------------------------------------------------------------
--                                                          --
-- BusyObjects Animation Export utility for gmax, v0.1      --
-- Copyright (c) 2002 by Bernd R. Fix <brf@brainon.ch>      --
--                                                          --
-- Based on code by (c) Copyright Wayland Reid, 2002        --
-- Based on code by (c) Copyright Zaddix, 2002              --
--                                                          --
-- Use this code in any way you see fit.                    --
-- If you use any/all of the code in your own scripts,      --
-- just credit all authors somewhere.                       --
--                                                          --
--------------------------------------------------------------

--------------------------------------------------------------
--	ExportBOD        
--	export a BusyObject Definition (BOD) from gmax anim data
--------------------------------------------------------------

fn ExportBOD node firstframe lastframe=
(
	local animLength = (lastframe - firstframe + 1) as integer
	format "Object= %\r\n" node.name
	if (node.parent != undefined) then
		format " Parent= %\r\n" node.parent.name
	else
		format " Parent= <NONE>\r\n"
	format " numFrames= %\r\n" animLength

	local t
	for t = firstframe to lastframe do
	(
--		if ((getKeyIndex node.pos.controller t) > 0) then
--		(
			at time t in coordsys parent objPos = node.pos
			format " % % % %" t objPos.x objPos.y objPos.z
--		)
--		if ((getKeyIndex node.rotation.controller t) > 0) then
--		(
			local objRot
			at time t in coordsys parent objRot = node.rotation;
			local rotVector = normalize (point3 objRot.x objRot.y objRot.z)
			local angle = degToRad(objRot.angle)
			format " % % % %" rotVector.x rotVector.y rotVector.z angle
--		)
		format "\r\n"
	)
	format "\r\n"

--	for c in node.children do ExportBOD c firstframe lastframe
)


--------------------------------------------------------------
--	Export Rollout
--------------------------------------------------------------

rollout ExportRollout "Export Trajectories" width:160 height:85 rolledUp:true
(
	spinner first_frame "" pos:[80,10] width:64 height:16 range:[0,10000,0] type:#integer scale:1
	spinner last_frame "" pos:[80,34] width:64 height:16 range:[0,10000,0] type:#integer scale:1
	label lbl1 "First Frame:" pos:[16,10] width:56 height:16
	label lbl2 "Last Frame:" pos:[16,34] width:56 height:16
	button export_anim_button "Export" pos:[16,58] width:64 height:24

	on export_anim_button pressed do
	(
		local node = selection[1]
		clearListener()
		format "# Exported from BusyObjects MaxSCRIPT v0.1 at %\r\n" localtime
		format "#\r\n"
		ExportBOD node first_frame.value last_frame.value
		clearSelection()
		select node
	)


	on ExportRollout open do callbacks.addscript #selectionSetChanged "selChanged()" id:#BOD_tool
	on ExportRollout close do callbacks.removeScripts #selectionSetChanged id:#BOD_tool
)

rollout AboutRollout "About" width:160 height:40 rolledUp:true
(
	label lbl1 "BusyObjects definition export" pos:[8,8] width:144 height:16
	label lbl2 "by Bernd R. Fix" pos:[8,24] width:136 height:16
)

-----------------------------------------------------------------------------------------------------
-----------------------------------------------------------------------------------------------------
---
---   Acutal window creation
---
-----------------------------------------------------------------------------------------------------
-----------------------------------------------------------------------------------------------------

-- create the rollout window 
if BOD_tool != undefined do
(
	closerolloutfloater BOD_tool
)
		
BOD_tool = newRolloutFloater "BusyObjects Tools" 189 240 0 100
addRollout ExportRollout	BOD_tool
addRollout AboutRollout		BOD_tool rolledUp:true

if IsSceneRedrawDisabled()==true do enablesceneredraw()


fn UpdateExportUI node =
(

	if (node != undefined) then
	(
		ExportRollout.export_anim_button.enabled = true
		ExportRollout.first_frame.enabled = true
		ExportRollout.last_frame.enabled = true

	)
	else
	(
		ExportRollout.export_anim_button.enabled = false
		ExportRollout.first_frame.enabled = false
		ExportRollout.last_frame.enabled = false
	)
)

------------------
--- selChanged ---
------------------

fn selChanged =
(
	UpdateExportUI selection[1]
)

-- Call this function once to set all the UI elements properly
selChanged()
